==> jc-1.4.0.tar.gz: javax/swing/plaf/ListUI.h <==
// public abstract class javax.swing.plaf.ListUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class b27b4d2b4abbb156 javax_swing_plaf_ListUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ListUI_H_
#define _JC_javax_swing_plaf_ListUI_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JList$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ListUI$sub_refs	_jc_javax_swing_plaf_ListUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ListUI$sub_nonrefs	_jc_javax_swing_plaf_ListUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ListUI$refs	_jc_javax_swing_plaf_ListUI$refs;
typedef struct _jc_javax_swing_plaf_ListUI$nonrefs	_jc_javax_swing_plaf_ListUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ListUI$object	_jc_javax_swing_plaf_ListUI$object;

typedef const struct _jc_javax_swing_plaf_ListUI$vmethods	_jc_javax_swing_plaf_ListUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ListUI$vtable	_jc_javax_swing_plaf_ListUI$vtable;
typedef const struct _jc_javax_swing_plaf_ListUI$vtype	_jc_javax_swing_plaf_ListUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ListUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *);

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_plaf_ListUI$method$getCellBounds$e3bf2983ca6c86de(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint, jint);
extern struct _jc_java_awt_Point$object *_jc_javax_swing_plaf_ListUI$method$indexToLocation$5b091aca8e6c3540(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint);
extern jint _jc_javax_swing_plaf_ListUI$method$locationToIndex$e191d24917e47bda(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_awt_Point$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_ListUI$method_info$getCellBounds$e3bf2983ca6c86de;
extern _jc_method _jc_javax_swing_plaf_ListUI$method_info$indexToLocation$5b091aca8e6c3540;
extern _jc_method _jc_javax_swing_plaf_ListUI$method_info$locationToIndex$e191d24917e47bda;

// Virtual methods structure
struct _jc_javax_swing_plaf_ListUI$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getCellBounds$e3bf2983ca6c86de)(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint, jint);
	struct _jc_java_awt_Point$object	*(*indexToLocation$5b091aca8e6c3540)(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint);
	jint	(*locationToIndex$e191d24917e47bda)(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_awt_Point$object *);
};

// Vtable
struct _jc_javax_swing_plaf_ListUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ListUI$vmethods	javax_swing_plaf_ListUI;
};

// Vtype
struct _jc_javax_swing_plaf_ListUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ListUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ListUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ListUI$refs {
    _jc_javax_swing_plaf_ListUI$sub_refs	javax_swing_plaf_ListUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ListUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ListUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ListUI$sub_nonrefs	javax_swing_plaf_ListUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ListUI$object {
	_jc_javax_swing_plaf_ListUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ListUI$vtype	*vtype;
	_jc_javax_swing_plaf_ListUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ListUI$vtype _jc_javax_swing_plaf_ListUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ListUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ListUI$class_object;

#endif	/* _JC_javax_swing_plaf_ListUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/ListUI.h <==
// public abstract class javax.swing.plaf.ListUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class b27b4d2b4abbb156 javax_swing_plaf_ListUI

// header file dependencies
// @dep_header javax_swing_plaf_ComponentUI

#include "javax/swing/plaf/ComponentUI.h"

#ifndef _JC_javax_swing_plaf_ListUI_H_
#define _JC_javax_swing_plaf_ListUI_H_

// Forward structure declarations
struct _jc_java_awt_Point$object;
struct _jc_java_awt_Rectangle$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JList$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_ListUI$sub_refs	_jc_javax_swing_plaf_ListUI$sub_refs;
typedef struct _jc_javax_swing_plaf_ListUI$sub_nonrefs	_jc_javax_swing_plaf_ListUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_ListUI$refs	_jc_javax_swing_plaf_ListUI$refs;
typedef struct _jc_javax_swing_plaf_ListUI$nonrefs	_jc_javax_swing_plaf_ListUI$nonrefs;
typedef struct _jc_javax_swing_plaf_ListUI$object	_jc_javax_swing_plaf_ListUI$object;

typedef const struct _jc_javax_swing_plaf_ListUI$vmethods	_jc_javax_swing_plaf_ListUI$vmethods;
typedef const struct _jc_javax_swing_plaf_ListUI$vtable	_jc_javax_swing_plaf_ListUI$vtable;
typedef const struct _jc_javax_swing_plaf_ListUI$vtype	_jc_javax_swing_plaf_ListUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_ListUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Rectangle$object *_jc_javax_swing_plaf_ListUI$method$getCellBounds$e3bf2983ca6c86de(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint, jint) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Point$object *_jc_javax_swing_plaf_ListUI$method$indexToLocation$5b091aca8e6c3540(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_ListUI$method$locationToIndex$e191d24917e47bda(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_ListUI$method_info$getCellBounds$e3bf2983ca6c86de;
extern _jc_method _jc_javax_swing_plaf_ListUI$method_info$indexToLocation$5b091aca8e6c3540;
extern _jc_method _jc_javax_swing_plaf_ListUI$method_info$locationToIndex$e191d24917e47bda;

// Virtual methods structure
struct _jc_javax_swing_plaf_ListUI$vmethods {
	struct _jc_java_awt_Rectangle$object	*(*getCellBounds$e3bf2983ca6c86de)(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint, jint) _JC_JCNI_ATTR;
	struct _jc_java_awt_Point$object	*(*indexToLocation$5b091aca8e6c3540)(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, jint) _JC_JCNI_ATTR;
	jint	(*locationToIndex$e191d24917e47bda)(_jc_env *, struct _jc_javax_swing_plaf_ListUI$object *, struct _jc_javax_swing_JList$object *, struct _jc_java_awt_Point$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_ListUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_ListUI$vmethods	javax_swing_plaf_ListUI;
};

// Vtype
struct _jc_javax_swing_plaf_ListUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_ListUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_ListUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_ListUI$refs {
    _jc_javax_swing_plaf_ListUI$sub_refs	javax_swing_plaf_ListUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_ListUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_ListUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_ListUI$sub_nonrefs	javax_swing_plaf_ListUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_ListUI$object {
	_jc_javax_swing_plaf_ListUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_ListUI$vtype	*vtype;
	_jc_javax_swing_plaf_ListUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_ListUI$vtype _jc_javax_swing_plaf_ListUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_ListUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_ListUI$class_object;

#endif	/* _JC_javax_swing_plaf_ListUI_H_ */
